build_schema_with_append_columns

Function build_schema_with_append_columns 

fn build_schema_with_append_columns(schema: &Schema) -> Schema
Build a new Arrow schema by appending _mz_diff (Int32) and _mz_timestamp (Int64) columns. These are user-visible Iceberg columns written in append mode. Parquet field IDs are assigned sequentially after the existing maximum field ID so the extended schema can be converted to a valid Iceberg schema via arrow_schema_to_schema.