async fn try_commit_batch(
table: Table,
snapshot_properties: Vec<(String, String)>,
data_files: Vec<DataFile>,
delete_files: Vec<DataFile>,
catalog: &dyn Catalog,
conn_namespace: &str,
conn_table: &str,
sink_version: u64,
frontier: &Antichain<Timestamp>,
batch_lower: &Antichain<Timestamp>,
batch_upper: &Antichain<Timestamp>,
metrics: &IcebergSinkMetrics,
) -> (Table, RetryResult<(), Error>)Expand description
Attempt a single commit of a batch of data files to an Iceberg table. On conflict or failure, reloads the table and returns a retryable error. On success, returns the updated table state.